==> openejb-jee-4.0.0-sources.jar: org/apache/openejb/jee/ConcurrentLockType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.jee;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;

/**
 * ejb-jar_3_1.xsd
 *
 * <p>Java class for concurrent-lock-typeType complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="concurrent-lock-typeType">
 *   &lt;simpleContent>
 *     &lt;restriction base="&lt;http://java.sun.com/xml/ns/javaee>string">
 *     &lt;/restriction>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "concurrent-lock-typeType")
@XmlEnum
public enum ConcurrentLockType {

    @XmlEnumValue("Read") READ("Read"),
    @XmlEnumValue("Write") WRITE("Write");

    private final String name;

    ConcurrentLockType(String name) {
       this.name = name;
   }

    public String toString() {
        return name;
    }

    public java.lang.String value() {
        return name();
    }

    public static ConcurrentLockType fromValue(java.lang.String v) {
        return valueOf(v);
    }

}

==> openejb-jee-4.7.5-sources.jar: org/apache/openejb/jee/ConcurrentLockType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.jee;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;

/**
 * ejb-jar_3_1.xsd
 * <p/>
 * <p>Java class for concurrent-lock-typeType complex type.
 * <p/>
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p/>
 * <pre>
 * &lt;complexType name="concurrent-lock-typeType">
 *   &lt;simpleContent>
 *     &lt;restriction base="&lt;http://java.sun.com/xml/ns/javaee>string">
 *     &lt;/restriction>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "concurrent-lock-typeType")
@XmlEnum
public enum ConcurrentLockType {

    @XmlEnumValue("Read")READ("Read"),
    @XmlEnumValue("Write")WRITE("Write");

    private final String name;

    ConcurrentLockType(final String name) {
        this.name = name;
    }

    public String toString() {
        return name;
    }

    public java.lang.String value() {
        return name();
    }

    public static ConcurrentLockType fromValue(final java.lang.String v) {
        return valueOf(v);
    }

}
